add_plugins

Function add_plugins 

pub fn add_plugins(app: &mut App)
Add plugins to app with NetworkPlugin disabled.

Also, for tests usually run in the same context, the logger and the subscriber in [LogPlugin] should only be initialized once. So only the first test executing this will have [LogPlugin] enabled. Other tests will have [LogPlugin] disabled.