pub struct MockClientHelper { /* private fields */ }Expand description
Contains the mocked client connection and helper methods to inject packets and read packets from the send stream.
Implementations
Sourceimpl MockClientHelper
impl MockClientHelper
pub fn new(conn: MockClientConnection) -> Self
Sourcepub fn send<P>(&mut self, packet: &P)
pub fn send<P>(&mut self, packet: &P)
Inject a packet to be treated as a packet inbound to the server. Panics if the packet cannot be sent.
Sourcepub fn collect_received(&mut self) -> PacketFrames
pub fn collect_received(&mut self) -> PacketFrames
Collect all packets that have been received by the client.
pub fn clear_received(&mut self)
pub fn confirm_initial_pending_teleports(&mut self)